-- ----------------------------
2024-04-08
-- ----------------------------
-- ----------------------------
-- 排号汇总表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_ph_queue`;
CREATE TABLE mortals_xhx_ph_queue(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `ordernumber` varchar(64) NOT NULL     COMMENT '预约编号，为空现场取号',
    `style` char(8) NOT NULL   DEFAULT '未叫号'  COMMENT '叫号状态 (未叫号,叫号中,完成)',
    `business` varchar(128) NOT NULL     COMMENT '业务名',
    `window_name` varchar(128) NOT NULL     COMMENT '窗口名',
    `window_fromnum` varchar(128) NOT NULL     COMMENT '窗口编号',
    `flownum` varchar(64) NOT NULL     COMMENT '流水编号,当天的第xxx号',
    `formernum` varchar(32) NOT NULL     COMMENT '呼叫转移号',
    `people_idcard` varchar(64) NOT NULL     COMMENT '身份证号',
    `people_name` varchar(64) NOT NULL     COMMENT '姓名',
    `people_sex` char(6) NOT NULL     COMMENT '性别',
    `people_phone` varchar(20) NOT NULL     COMMENT '手机号',
    `workman_name` varchar(32) NOT NULL     COMMENT '工作人员姓名',
    `workman_number` varchar(20) NOT NULL     COMMENT '工作人员工号',
    `taketime` datetime      COMMENT '取号时间',
    `calltime` datetime      COMMENT '叫号时间',
    `endtime` datetime      COMMENT '结束时间',
    `wait_time` int(9) NOT NULL   DEFAULT '0'  COMMENT '等待时间,单位s',
    `handle_time` int(9) NOT NULL   DEFAULT '0'  COMMENT '办理时间,单位s',
    `device_name` varchar(128) NOT NULL     COMMENT '取号设备名',
    `call_name` varchar(128) NOT NULL     COMMENT '呼叫设备',
    `matter_name` varchar(256) NOT NULL     COMMENT '事项名',
    `queueid` varchar(128) NOT NULL     COMMENT '排号队列ID',
    `wy_signin` varchar(16) NOT NULL   DEFAULT '现场取号'  COMMENT '取号方式 (现场取号,微信取号)',
    `section_name` varchar(128) NOT NULL     COMMENT '部门名称',
    `hall_name` varchar(128) NOT NULL     COMMENT '大厅名称',
    `device_type` varchar(32) NOT NULL   DEFAULT '排号机'  COMMENT '取号设备类型',
    `site_id` bigint(20) NOT NULL   DEFAULT '0'  COMMENT '站点Id',
    `site_code` varchar(128) NOT NULL     COMMENT '站点编码',
    `site_name` varchar(128)      COMMENT '站点名称',
    `ext_num` varchar(128) NOT NULL     COMMENT '扩展编号',
    `create_user_id` bigint(20)      COMMENT '创建用户',
    `create_time` datetime NOT NULL     COMMENT '创建时间',
    `update_time` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
,KEY `style` (`style`) USING BTREE
,KEY `business` (`business`) USING BTREE
,KEY `window_fromnum` (`window_fromnum`) USING BTREE
,KEY `people_idcard` (`people_idcard`) USING BTREE
,KEY `people_phone` (`people_phone`) USING BTREE
,KEY `workman_number` (`workman_number`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='排号汇总';


-- ----------------------------
-- 排号汇总统计表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_ph_queue_stat`;
CREATE TABLE `mortals_xhx_ph_queue_stat` (
    `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT 'ID',
    `site_id` bigint(20)    DEFAULT '0'  COMMENT '站点Id',
    `site_code` varchar(128)      COMMENT '站点编码',
    `site_name` varchar(128)      COMMENT '站点名称',
    `business` varchar(128) NOT NULL     COMMENT '业务名',
    `section_name` varchar(128) NOT NULL     COMMENT '部门',
    `hall_name` varchar(128) DEFAULT NULL COMMENT '大厅名称',
    `wait_time` int(9) DEFAULT '0' COMMENT '平均等待时间,单位s',
    `window_fromnum` varchar(128) NOT NULL     COMMENT '窗口编号',
    `ph_count` int(9) NOT NULL COMMENT '取号数量',
    `year` int(9) NOT NULL COMMENT '年',
    `month` int(9) NOT NULL COMMENT '月',
    `day` int(9) NOT NULL COMMENT '日',
    `createTime` datetime NOT NULL COMMENT '创建时间',
    `updateUserId` bigint(20) DEFAULT NULL COMMENT '更新用户',
    `updateTime` datetime DEFAULT NULL COMMENT '更新时间',
    PRIMARY KEY (`id`) USING BTREE
,KEY `year` (`year`) USING BTREE
,KEY `month` (`month`) USING BTREE
,KEY `day` (`day`) USING BTREE
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='排队叫号汇总统计';


-- ----------------------------
-- 评价汇总表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_pj_evaluate_stat`;
CREATE TABLE `mortals_xhx_pj_evaluate_stat` (
`id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT 'ID',
`site_id` bigint(20)    DEFAULT '0'  COMMENT '站点Id',
`site_code` varchar(128)      COMMENT '站点编码',
`site_name` varchar(128)      COMMENT '站点名称',
`section_name` varchar(128) NOT NULL     COMMENT '部门',
`pj_option` varchar(32) NOT NULL     COMMENT '评价选项(非常满意,满意,基本满意,不满意,非常不满意)',
`window_fromnum` varchar(128) NOT NULL     COMMENT '窗口编号',
`hall_name` varchar(128) DEFAULT NULL COMMENT '大厅名称',
`pj_count` int(9) NOT NULL COMMENT '评价数量',
`year` int(9) NOT NULL COMMENT '年',
`month` int(9) NOT NULL COMMENT '月',
`day` int(9) NOT NULL COMMENT '日',
`createTime` datetime NOT NULL COMMENT '创建时间',
`updateUserId` bigint(20) DEFAULT NULL COMMENT '更新用户',
`updateTime` datetime DEFAULT NULL COMMENT '更新时间',
PRIMARY KEY (`id`) USING BTREE
    ,KEY `year` (`year`) USING BTREE
    ,KEY `month` (`month`) USING BTREE
    ,KEY `day` (`day`) USING BTREE
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='评价汇总统计';


-- ----------------------------
-- 评价汇总统计表
-- ----------------------------
CREATE TABLE mortals_xhx_pj_evaluate(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `people_idcard` varchar(64) NOT NULL     COMMENT '评价人身份证号',
    `people_name` varchar(64) NOT NULL     COMMENT '评价人姓名',
    `people_sex` char(6) NOT NULL     COMMENT '评价人性别',
    `people_phone` varchar(20) NOT NULL     COMMENT '评价人手机号',
    `pj_option` varchar(32) NOT NULL     COMMENT '评价选项(非常满意,满意,基本满意,不满意,非常不满意)',
    `content_tag` varchar(255) NOT NULL     COMMENT '评价标签',
    `pic_url` varchar(128) NOT NULL     COMMENT '评价人图片地址',
    `section_name` varchar(128) NOT NULL     COMMENT '部门',
    `hall_name` varchar(128) NOT NULL     COMMENT '大厅',
    `pj_source` varchar(20) NOT NULL     COMMENT '评价来源 (安卓,导视机,微信)',
    `opinion` varchar(512)      COMMENT '手输意见',
    `window_name` varchar(128) NOT NULL     COMMENT '窗口名',
    `window_fromnum` varchar(128) NOT NULL     COMMENT '窗口编号',
    `flounum` varchar(20)      COMMENT '排号编号',
    `pjxt` varchar(32)    DEFAULT '窗口评价'  COMMENT '窗口评价(自助服务终端,背靠背评价,微官网)',
    `workman_name` varchar(32) NOT NULL     COMMENT '工作人员姓名',
    `workman_number` varchar(20) NOT NULL     COMMENT '工作人员工号',
    `devicenum` varchar(64)      COMMENT '评价器mac',
    `evaluatestatus` varchar(32)    DEFAULT '等待评价'  COMMENT '评价状态(等待评价,完成,截图有误,用户截图签名超时,用户评价超时,收到图片等待签名',
    `evaluatetype` char(8)    DEFAULT '截图'  COMMENT '截图还是评价 (截图,评价)',
    `photobefor` varchar(256) NOT NULL     COMMENT '截图地址',
    `photoautograph` varchar(256)      COMMENT '签字图片',
    `picture` varchar(256) NOT NULL     COMMENT '抓拍评价人照片',
    `process` varchar(256) NOT NULL     COMMENT '音频视频地址',
    `eyevaluate` varchar(16)    DEFAULT '未标记'  COMMENT '评价标记（未标记,标记非恶意差评,标记恶意差评)',
    `pj_type` varchar(16) NOT NULL   DEFAULT '窗口评价'  COMMENT '评价指向 (窗口评价,部门评价,排号评价)',
    `pj_time` datetime      COMMENT '评价时间',
    `site_id` bigint(20)    DEFAULT '0'  COMMENT '站点Id',
    `site_code` varchar(128)      COMMENT '站点编码',
    `site_name` varchar(128)      COMMENT '站点名称',
    `ext_num` varchar(128)      COMMENT '扩展编号',
    `create_user_id` bigint(20)      COMMENT '创建用户',
    `create_time` datetime NOT NULL     COMMENT '创建时间',
    `update_time` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
,KEY `people_idcard` (`people_idcard`) USING BTREE
,KEY `people_phone` (`people_phone`) USING BTREE
,KEY `pj_option` (`pj_option`) USING BTREE
,KEY `pj_source` (`pj_source`) USING BTREE
,KEY `site_id` (`site_id`) USING BTREE
,KEY `site_code` (`site_code`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='评价汇总';
DROP TABLE IF EXISTS `mortals_xhx_pj_evaluate_stat`;

